import {NgModule} from "@angular/core";
import {RouterModule, Routes} from "@angular/router";
import {LoginComponent} from "@app/components/login/login.component";
import {PageNotFoundComponent} from "@app/components/page-not-found/page-not-found.component";
import {AppRoutesEnum} from "@app/shared/enums/routes.enum";
import {AuthGuardService} from "@app/shared/services/auth-guard.service";
import {TRANSLATE} from "@app/shared/utils/translate.util";


const routes: Routes = [
  {
    path: AppRoutesEnum.access,
    loadChildren: "./access/access.module#AccessModule",
    data: {
      breadcrumb: TRANSLATE("breadcrumb.access.root"),
    },
  },
  {
    path: AppRoutesEnum.deposit,
    loadChildren: "./deposit/deposit.module#DepositModule",
    data: {
      breadcrumb: TRANSLATE("breadcrumb.deposit.root"),
    },
    canActivate: [AuthGuardService],
  },
  {
    path: AppRoutesEnum.organizationalUnit,
    loadChildren: "./organizational-unit/organizational-unit.module#OrganizationalUnitModule",
    data: {
      breadcrumb: TRANSLATE("breadcrumb.organizationalUnit.root"),
    },
    canActivate: [AuthGuardService],
  },
  {
    path: AppRoutesEnum.login,
    component: LoginComponent,
  },
  {
    path: AppRoutesEnum.root,
    redirectTo: AppRoutesEnum.access,
    pathMatch: "full",
  },
  {
    path: AppRoutesEnum.index,
    redirectTo: AppRoutesEnum.access,
    pathMatch: "full",
  },
  {
    path: AppRoutesEnum.home,
    redirectTo: AppRoutesEnum.access,
    pathMatch: "full",
  },
  {
    path: "**",
    component: PageNotFoundComponent,
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule],
})
export class AppRoutingModule {
}
