import {HttpClient, HttpClientModule} from "@angular/common/http";
import {ErrorHandler, NgModule} from "@angular/core";
import {BrowserModule} from "@angular/platform-browser";
import {BrowserAnimationsModule} from "@angular/platform-browser/animations";
import {AppRoutingModule} from "@app/app-routing.module";
import {AppState} from "@app/app.state";
import {MainToolbarMobileComponent} from "@app/components/main-toolbar-mobile/main-toolbar-mobile.component";
import {ErrorsHandlerService} from "@app/errors-handler.service";
import {ApiModule} from "@app/generated-api/api.module";
import {BASE_PATH} from "@app/generated-api/variables";
import {SharedModule} from "@app/shared/shared.module";
import {TranslateLoader, TranslateModule} from "@ngx-translate/core";
import {TranslateHttpLoader} from "@ngx-translate/http-loader";
import {NgxsReduxDevtoolsPluginModule} from "@ngxs/devtools-plugin";
import {NgxsLoggerPluginModule} from "@ngxs/logger-plugin";
import {NgxsRouterPluginModule} from "@ngxs/router-plugin";
import {NgxsModule} from "@ngxs/store";
import {environment} from "../environments/environment";
import {AppComponent} from "./app.component";
import {authConfig, authModuleConfig} from "./auth.config";
import {FooterComponent} from "./components/footer/footer.component";
import {HomeComponent} from "./components/home/home.component";
import {LanguageSelectorComponent} from "./components/language-selector/language-selector.component";
import {LoginComponent} from "./components/login/login.component";
import {MainToolbarComponent} from "./components/main-toolbar/main-toolbar.component";
import {PageNotFoundComponent} from "./components/page-not-found/page-not-found.component";
import {AuthConfig} from "@app/oauth/auth.config";
import {OAuthStorage} from "@app/oauth/types";
import {OAuthModuleConfig} from "@app/oauth/oauth-module.config";
import {DlcmOauthOidicModule} from "@app/oauth/dlcm-oauth-oidic.module";
import {MainToolbarDirective} from "./directives/main-toolbar.directive";

const components = [
  AppComponent,
  FooterComponent,
  HomeComponent,
  LanguageSelectorComponent,
  LoginComponent,
  MainToolbarComponent,
  MainToolbarMobileComponent,
  PageNotFoundComponent,
];

@NgModule({
  declarations: [
    ...components,
    MainToolbarDirective,
  ],
  imports: [
    // angular
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,

    // NgXs
    NgxsModule.forRoot([
      AppState,
    ], {
      developmentMode: !environment.production, // Allow to enable freeze store in dev env
    }),

    NgxsModule.forRoot([
      AppState,
    ], {
      developmentMode: !environment.production, // Allow to enable freeze store in dev env
    }),
    NgxsLoggerPluginModule.forRoot({
      logger: console,
      collapsed: false,
      disabled: environment.production,
    }),
    NgxsReduxDevtoolsPluginModule.forRoot({
      disabled: environment.production,
    }),
    NgxsRouterPluginModule.forRoot(),

    // Oauth2
    DlcmOauthOidicModule.forRoot(authModuleConfig),

    // NgTranslate
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: HttpLoaderFactory,
        deps: [HttpClient],
      },
    }),

    // Shared
    SharedModule,
    ApiModule,

    // App
    AppRoutingModule
  ],
  providers: [
    {
      provide: OAuthModuleConfig,
      useValue: authModuleConfig,
    },
    {
      provide: OAuthStorage,
      useValue: sessionStorage,
    },
    {
      provide: AuthConfig,
      useValue: authConfig,
    },
    {
      provide: BASE_PATH,
      useValue: environment.API_BASE_PATH,
    },
    {
      provide: ErrorHandler,
      useClass: ErrorsHandlerService,
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {
}

// required for AOT compilation
export function HttpLoaderFactory(http: HttpClient) {
  return new TranslateHttpLoader(http);
}
