import {ChangeDetectionStrategy, Component, Input} from "@angular/core";
import {FormBuilder, Validators} from "@angular/forms";
import {
  DepositsModel,
  LanguagesModel,
  LicensesModel,
  OrganizationalUnitsModel,
  PreservationPoliciesModel,
  SubmissionPoliciesModel,
} from "@app/generated-api";
import {AbstractFormComponent} from "@app/shared/components/abstract-form/abstract-form.component";
import {DateUtil} from "@app/shared/utils/date.util";
import AccessModelEnum = DepositsModel.AccessModelEnum;

@Component({
  selector: "dlcm-form-deposit",
  templateUrl: "./form.component.html",
  styleUrls: ["../../../shared/components/abstract-form/abstract-form.component.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class FormComponent extends AbstractFormComponent<DepositsModel> {
  organizationalUnitId = "organizationalUnitId";
  title = "title";
  description = "description";
  languageId = "languageId";
  publicationDate = "publicationDate";
  collectionBegin = "collectionBegin";
  collectionEnd = "collectionEnd";
  author = "author";
  accessLevel = "accessLevel";
  hasEmbargo = "hasEmbargo";
  licenseId = "licenseId";
  submissionPolicyId = "submissionPolicyId";
  preservationPolicyId = "preservationPolicyId";

  accessModelEnum = AccessModelEnum;

  @Input()
  languages: LanguagesModel[];

  @Input()
  licenses: LicensesModel[];

  @Input()
  submissionPolicies: SubmissionPoliciesModel[];

  @Input()
  preservationPolicies: PreservationPoliciesModel[];

  @Input()
  organizationalUnits: OrganizationalUnitsModel[];

  constructor(protected fb: FormBuilder) {
    super();
  }

  protected initNewForm() {
    this.form = this.fb.group({
      organizationalUnitId: ["", Validators.required],
      title: ["", Validators.required],
      description: ["", Validators.required],
      languageId: [""],
      publicationDate: [""],
      collectionBegin: [""],
      collectionEnd: [""],
      author: [""],
      accessLevel: [AccessModelEnum.PUBLIC],
      hasEmbargo: [false],
      licenseId: [""],
      submissionPolicyId: [""],
      preservationPolicyId: [""],
    });
  }

  protected bindFormTo(deposit: DepositsModel) {
    this.form = this.fb.group({
      organizationalUnitId: [deposit.organizationalUnitId, Validators.required],
      title: [deposit.title, Validators.required],
      description: [deposit.description, Validators.required],
      languageId: [deposit.languageId],
      publicationDate: [deposit.publicationDate],
      collectionBegin: [deposit.collectionBegin],
      collectionEnd: [deposit.collectionEnd],
      author: [""],
      accessLevel: [deposit.access],
      hasEmbargo: [deposit.hasEmbargo],
      licenseId: [deposit.licenseId],
      submissionPolicyId: [deposit.submissionPolicyId],
      preservationPolicyId: [deposit.preservationPolicyId],
    });
  }

  protected treatmentBeforeSubmit(deposit: DepositsModel): DepositsModel {
    deposit.publicationDate = DateUtil.convertToISO8601(deposit.publicationDate);
    // deposit.collectionBegin = DateUtil.convertToDateTime(deposit.collectionBegin);
    return deposit;
  }
}
