import {DepositsModel} from "@app/generated-api";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {StringUtil} from "@app/shared/utils/string.util";

const state = StateEnum.deposit;

export class DepositChangeQueryParameters extends ChangeQueryParametersCrud {
  static readonly type = StringUtil.format(ChangeQueryParametersCrud.abstractType, state);

  constructor(public queryParameters: QueryParametersModel) {
    super(queryParameters);
  }
}

export class DepositGetAll extends GetAllCrud {
  static readonly type = StringUtil.format(GetAllCrud.abstractType, state);

  constructor(public queryParameters?: QueryParametersModel) {
    super(queryParameters);
  }
}

export class DepositGetAllSuccess extends GetAllSuccessCrud<DepositsModel> {
  static readonly type = StringUtil.format(GetAllSuccessCrud.abstractType, state);

  constructor(public list: CollectionTypedModel<DepositsModel>) {
    super(list);
  }
}

export class DepositGetAllFail extends GetAllFailCrud {
  static readonly type = StringUtil.format(GetAllFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositGetById extends GetByIdCrud {
  static readonly type = StringUtil.format(GetByIdCrud.abstractType, state);

  constructor(public id: string) {
    super(id);
  }
}

export class DepositGetByIdSuccess extends GetByIdSuccessCrud<DepositsModel> {
  static readonly type = StringUtil.format(GetByIdSuccessCrud.abstractType, state);

  constructor(public model: DepositsModel) {
    super(model);
  }
}

export class DepositGetByIdFail extends GetByIdFailCrud {
  static readonly type = StringUtil.format(GetByIdFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositCreate extends CreateCrud<DepositsModel> {
  static readonly type = StringUtil.format(CreateCrud.abstractType, state);

  constructor(public model: DepositsModel) {
    super(model);
  }
}

export class DepositCreateSuccess extends CreateSuccessCrud {
  static readonly type = StringUtil.format(CreateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositCreateFail extends CreateFailCrud {
  static readonly type = StringUtil.format(CreateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositUpdate extends UpdateCrud<DepositsModel> {
  static readonly type = StringUtil.format(UpdateCrud.abstractType, state);

  constructor(public model: DepositsModel) {
    super(model);
  }
}

export class DepositUpdateSuccess extends UpdateSuccessCrud {
  static readonly type = StringUtil.format(UpdateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositUpdateFail extends UpdateFailCrud {
  static readonly type = StringUtil.format(UpdateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositDelete extends DeleteCrud {
  static readonly type = StringUtil.format(DeleteCrud.abstractType, state);

  constructor(public resId: string) {
    super(resId);
  }
}

export class DepositDeleteSuccess extends DeleteSuccessCrud {
  static readonly type = StringUtil.format(DeleteSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class DepositDeleteFail extends DeleteFailCrud {
  static readonly type = StringUtil.format(DeleteFailCrud.abstractType, state);

  constructor() {
    super();
  }
}
