import {
  DepositChangeQueryParameters,
  DepositCreate,
  DepositCreateFail,
  DepositCreateSuccess,
  DepositDelete,
  DepositDeleteFail,
  DepositDeleteSuccess,
  DepositGetAll,
  DepositGetAllFail,
  DepositGetAllSuccess,
  DepositGetById,
  DepositGetByIdFail,
  DepositGetByIdSuccess,
  DepositUpdate,
  DepositUpdateFail,
  DepositUpdateSuccess,
} from "@app/deposit/deposit.action";
import {DepositsModel} from "@app/generated-api";
import {CrudState, CrudStateModel} from "@app/shared/crud.state";
import {PreIngestResourceApiEnum} from "@app/shared/enums/api.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {ApiService} from "@app/shared/services/api.service";
import {Action, State, StateContext} from "@ngxs/store";
import {Observable} from "rxjs";

export interface DepositStateModel extends CrudStateModel<DepositsModel> {
}

@State<DepositStateModel>({
  name: StateEnum.deposit,
  defaults: {
    total: 0,
    isLoading: false,
    list: [],
    current: null,
    queryParameters: new QueryParametersModel(),
  },
})
export class DepositState extends CrudState<DepositsModel> {
  protected urlResource: string;
  protected state: StateEnum;

  constructor(protected apiService: ApiService) {
    super(apiService);
    this.state = StateEnum.deposit;
    this.urlResource = PreIngestResourceApiEnum.deposits;
  }

  @Action(DepositChangeQueryParameters)
  changeQueryParameters(ctx: StateContext<DepositStateModel>, action: DepositChangeQueryParameters): void {
    super.changeQueryParameters(ctx, action);
  }

  @Action(DepositGetAll, {cancelUncompleted: true})
  getAll(ctx: StateContext<DepositStateModel>, action: DepositGetAll): Observable<CollectionTypedModel<DepositsModel>> {
    return super.getAll(ctx, action);
  }

  @Action(DepositGetAllSuccess)
  getAllSuccess(ctx: StateContext<DepositStateModel>, action: DepositGetAllSuccess): void {
    super.getAllSuccess(ctx, action);
  }

  @Action(DepositGetAllFail)
  getAllFail(ctx: StateContext<DepositStateModel>, action: DepositGetAllFail): void {
    super.getAllFail(ctx, action);
  }

  @Action(DepositGetById, {cancelUncompleted: true})
  getById(ctx: StateContext<DepositStateModel>, action: DepositGetById): Observable<DepositsModel> {
    return super.getById(ctx, action);
  }

  @Action(DepositGetByIdSuccess)
  getByIdSuccess(ctx: StateContext<DepositStateModel>, action: DepositGetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
  }

  @Action(DepositGetByIdFail)
  getByIdFail(ctx: StateContext<DepositStateModel>, action: DepositGetByIdFail): void {
    super.getByIdFail(ctx, action);
  }

  @Action(DepositCreate, {cancelUncompleted: true})
  create(ctx: StateContext<DepositStateModel>, action: DepositCreate): Observable<DepositsModel> {
    return super.create(ctx, action);
  }

  @Action(DepositCreateSuccess)
  createSuccess(ctx: StateContext<DepositStateModel>, action: DepositCreateSuccess): void {
    super.createSuccess(ctx, action);
  }

  @Action(DepositCreateFail)
  createFail(ctx: StateContext<DepositStateModel>, action: DepositCreateFail): void {
    super.createFail(ctx, action);
  }

  @Action(DepositUpdate, {cancelUncompleted: true})
  update(ctx: StateContext<DepositStateModel>, action: DepositUpdate): Observable<DepositsModel> {
    return super.update(ctx, action);
  }

  @Action(DepositUpdateSuccess)
  updateSuccess(ctx: StateContext<DepositStateModel>, action: DepositUpdateSuccess): void {
    super.updateSuccess(ctx, action);
  }

  @Action(DepositUpdateFail)
  updateFail(ctx: StateContext<DepositStateModel>, action: DepositUpdateFail): void {
    super.updateFail(ctx, action);
  }

  @Action(DepositDelete, {cancelUncompleted: true})
  delete(ctx: StateContext<DepositStateModel>, action: DepositDelete): Observable<DepositsModel> {
    return super.delete(ctx, action);
  }

  @Action(DepositDeleteSuccess)
  deleteSuccess(ctx: StateContext<DepositStateModel>, action: DepositDeleteSuccess): void {
    super.deleteSuccess(ctx, action);
  }

  @Action(DepositDeleteFail)
  deleteFail(ctx: StateContext<DepositStateModel>, action: DepositDeleteFail): void {
    super.deleteFail(ctx, action);
  }
}
