import {ChangeDetectionStrategy, Component, OnInit} from "@angular/core";
import {MatDialog} from "@angular/material";
import {ActivatedRoute} from "@angular/router";
import {DepositStateModel} from "@app/deposit/deposit.state";
import {
  DepositsModel,
  LanguagesModel,
  LicensesModel,
  OrganizationalUnitsModel,
  PreservationPoliciesModel,
  SubmissionPoliciesModel,
} from "@app/generated-api";
import {OrgUnitGetAll} from "@app/shared/organizational-unit.action";
import {OrganizationalUnitModule} from "@app/organizational-unit/organizational-unit.module";
import {OrganizationalUnitStateModel} from "@app/shared/organizational-unit.state";
import {StateEnum} from "@app/shared/enums/state.enum";
import {LanguageStateModel} from "@app/shared/language.state";
import {LicenseStateModel} from "@app/shared/license.state";
import {PreservationPolicyStateModel} from "@app/shared/preservation-policy.state";
import {SharedStateModel} from "@app/shared/shared.state";
import {SubmissionPolicyStateModel} from "@app/shared/submission-policy.state";
import {TRANSLATE} from "@app/shared/utils/translate.util";
import {AbstractDetailView} from "@app/shared/views/abstract-detail/abstract-detail.view";
import {Select, Store} from "@ngxs/store";
import {Observable} from "rxjs";

@Component({
  selector: "dlcm-detail-view",
  templateUrl: "./detail.view.html",
  styleUrls: ["../../../shared/views/abstract-detail/abstract-detail.view.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DetailView extends AbstractDetailView<DepositsModel, DepositStateModel> implements OnInit {
  @Select((state) => ((state[StateEnum.shared] as SharedStateModel).language as LanguageStateModel).list) languages$: Observable<LanguagesModel[]>;
  @Select((state) => ((state[StateEnum.shared] as SharedStateModel).license as LicenseStateModel).list) licenses$: Observable<LicensesModel[]>;
  @Select((state) => ((state[StateEnum.shared] as SharedStateModel).submissionPolicy as SubmissionPolicyStateModel).list) submissionPolicies$: Observable<SubmissionPoliciesModel[]>;
  @Select((state) => ((state[StateEnum.shared] as SharedStateModel).preservationPolicy as PreservationPolicyStateModel).list) preservationPolicies$: Observable<PreservationPoliciesModel[]>;
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).list) organizationalUnits$: Observable<OrganizationalUnitModule[]>;

  readonly KEY_PARAM_NAME: string = "title";
  readonly KEY_DELETE_BUTTON: string = TRANSLATE("deposit.delete");
  readonly KEY_EDIT_BUTTON: string = TRANSLATE("deposit.edit");

  constructor(protected store: Store,
              protected route: ActivatedRoute,
              public dialog: MatDialog) {
    super(store, route, dialog, StateEnum.deposit);
  }

  ngOnInit() {
    super.ngOnInit();
    this.store.dispatch(new OrgUnitGetAll());
  }
}
