import {ChangeDetectionStrategy, Component} from "@angular/core";
import {DepositStateModel} from "@app/deposit/deposit.state";
import {DepositsModel} from "@app/generated-api";
import {FieldTypeEnum} from "@app/shared/enums/field-type.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {TRANSLATE} from "@app/shared/utils/translate.util";
import {AbstractListView} from "@app/shared/views/abstract-list/abstract-list.view";
import {TranslateService} from "@ngx-translate/core";
import {Store} from "@ngxs/store";

@Component({
  selector: "dlcm-list-view",
  templateUrl: "../../../shared/views/abstract-list/abstract-list.view.html",
  styleUrls: ["../../../shared/views/abstract-list/abstract-list.view.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ListView extends AbstractListView<DepositsModel, DepositStateModel> {
  readonly KEY_CREATE_BUTTON: string = TRANSLATE("deposit.new");
  readonly KEY_REFRESH_BUTTON: string = TRANSLATE("deposit.refresh");

  constructor(protected store: Store, private translate: TranslateService) {
    super(store, StateEnum.deposit);
  }

  defineColumns() {
    // TODO Use typeof to get interface propertie name
    this.columns = [
      {field: "title", header: TRANSLATE("deposit.table.header.title"), type: FieldTypeEnum.string, order: 0},
      {field: "publicationDate", header: TRANSLATE("deposit.table.header.publicationDate"), type: FieldTypeEnum.date, order: 0},
      {field: "creation.when", header: TRANSLATE("deposit.table.header.creation.when"), type: FieldTypeEnum.datetime, order: 0},
      {field: "lastUpdate.when", header: TRANSLATE("deposit.table.header.lastUpdate.when"), type: FieldTypeEnum.datetime, order: 0},
      {field: "status", header: TRANSLATE("deposit.table.header.status"), type: FieldTypeEnum.string, order: 0},
    ];
  }
}
