import {Directive, EventEmitter, Input, Output} from "@angular/core";
import {BaseDirective} from "@app/shared/directives/base.directive";
import {LanguagesEnum} from "@app/shared/enums/languages.enum";
import {RoutesEnum} from "@app/shared/enums/routes.enum";
import {OAuthService} from "@app/oauth/oauth-service";

@Directive({
  selector: "[dlcmMainToolbar]"
})
export class MainToolbarDirective extends BaseDirective {
  @Input()
  currentPath: string;

  @Input()
  currentLanguage: LanguagesEnum;

  @Output()
  navigateEvent: EventEmitter<string>;

  @Output()
  languageEvent: EventEmitter<LanguagesEnum>;

  @Output()
  logoutEvent = new EventEmitter<void>();

  organizationalUnitPath: string = RoutesEnum.organizationalUnit;
  depositPath: string = RoutesEnum.deposit;

  accessPath: string = RoutesEnum.access;

  isOpen: boolean;

  private logged = false;

  get loggedIn(): boolean {
    return this.logged;
  }

  @Input()
  set loggedIn(val: boolean) {
    this.logged = val;
  }

  constructor(private oauthService: OAuthService) {
    super();
    this.navigateEvent = new EventEmitter();
    this.languageEvent = new EventEmitter();
    this.isOpen = false;
  }

  navigate(path: string) {
    this.navigateEvent.emit(path);
  }

  useLanguage(language: LanguagesEnum) {
    this.languageEvent.emit(language);
  }

  toggleMenu() {
    this.isOpen = !this.isOpen;
  }

  login() {
    this.oauthService.initAuthorizationCodeFlow();
  }

  logout() {
    this.logoutEvent.emit();
  }
}
