import {Injectable} from "@angular/core";
import {OAuthStorage} from "@app/oauth/types";

/**
 * Custom storage in memory for sensible data like token
 * (cf best practice https://auth0.com/docs/security/store-tokens)
 */
@Injectable()
export class DlcmStorage extends OAuthStorage {
  private storageValues: Map<string, string>;

  constructor() {
    super();
    this.storageValues = new Map<string, string>();
  }

  getItem(key: string): string | null {
    console.log("retrieve " + key);
    return this.storageValues[key];
  }

  removeItem(key: string): void {
    this.storageValues.delete(key);
  }

  setItem(key: string, data: string): void {
    console.log("store " + key, data);
    this.storageValues.set(key, data);
  }

}
