import {HttpErrorResponse} from "@angular/common/http";
import {ErrorHandler, Injectable, Injector} from "@angular/core";
import {MatSnackBar} from "@angular/material";

@Injectable()
export class ErrorsHandlerService implements ErrorHandler {
  durationInSeconds = 5;

  constructor(private injector: Injector, private snackBar: MatSnackBar) {
  }

  handleError(error: Error | HttpErrorResponse) {
    // const notificationService = this.injector.get(NotificationService);

    if (error instanceof HttpErrorResponse) {
      // Server or connection error happened
      if (!navigator.onLine) {
        this.openSnackBar("No Internet Connection");
      } else {
        // Handle Http Error (error.status === 403, 404...)
        // return notificationService.notify(`${error.status} - ${error.message}`);
        const message = `${error.status} - ${error.message}`;
        console.error("Error: ", message);
        this.openSnackBar(message);
      }
    } else {
      // Handle Client Error (Angular Error, ReferenceError...)
    }

    // Do whatever you like with the error (send it to the server?)
    // And log it to the console
    console.error("Error: ", error);
  }

  openSnackBar(message: string) {
    this.snackBar.open(message, "close", {
      duration: this.durationInSeconds * 1000,
    });
  }
}
