import {ChangeDetectionStrategy, Component} from "@angular/core";
import {FormBuilder, Validators} from "@angular/forms";
import {OrganizationalUnitsModel} from "@app/generated-api";
import {AbstractFormComponent} from "@app/shared/components/abstract-form/abstract-form.component";
import {DateUtil} from "@app/shared/utils/date.util";

@Component({
  selector: "dlcm-form-orgunit",
  templateUrl: "./form.component.html",
  styleUrls: ["../../../shared/components/abstract-form/abstract-form.component.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class FormComponent extends AbstractFormComponent<OrganizationalUnitsModel> {
  name = "name";
  description = "description";
  isEmpty = "isEmpty";
  closingDate = "closingDate";
  openingDate = "openingDate";
  open = "open";

  constructor(private fb: FormBuilder) {
    super();
  }

  protected initNewForm() {
    this.form = this.fb.group({
      name: ["", Validators.required],
      description: ["", Validators.required],
      openingDate: [""],
      closingDate: [""],
      isEmpty: [false],
      open: [false],
    });
  }

  protected bindFormTo(organizationalUnit: OrganizationalUnitsModel) {
    this.form = this.fb.group({
      name: [organizationalUnit.name, Validators.required],
      description: [organizationalUnit.description, Validators.required],
      openingDate: [organizationalUnit.openingDate],
      closingDate: [organizationalUnit.closingDate],
      isEmpty: [organizationalUnit.isEmpty],
      open: [organizationalUnit.open],
    });
  }

  protected treatmentBeforeSubmit(organizationalUnit: OrganizationalUnitsModel): OrganizationalUnitsModel {
    organizationalUnit.openingDate = DateUtil.convertToISO8601(organizationalUnit.openingDate);
    organizationalUnit.closingDate = DateUtil.convertToISO8601(organizationalUnit.closingDate);
    return organizationalUnit;
  }
}
