import {ChangeDetectionStrategy, Component} from "@angular/core";
import {OrganizationalUnitsModel} from "@app/generated-api";
import {OrganizationalUnitStateModel} from "@app/shared/organizational-unit.state";
import {FieldTypeEnum} from "@app/shared/enums/field-type.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {TRANSLATE} from "@app/shared/utils/translate.util";
import {AbstractListView} from "@app/shared/views/abstract-list/abstract-list.view";
import {TranslateService} from "@ngx-translate/core";
import {Store} from "@ngxs/store";

@Component({
  selector: "dlcm-list-view",
  templateUrl: "../../../shared/views/abstract-list/abstract-list.view.html",
  styleUrls: ["../../../shared/views/abstract-list/abstract-list.view.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ListView extends AbstractListView<OrganizationalUnitsModel, OrganizationalUnitStateModel> {
  readonly KEY_CREATE_BUTTON: string = TRANSLATE("organizationalUnit.new");
  readonly KEY_REFRESH_BUTTON: string = TRANSLATE("organizationalUnit.refresh");

  constructor(protected store: Store, private translate: TranslateService) {
    super(store, StateEnum.organizationalUnit);
  }

  defineColumns() {
    // TODO Use typeof to get interface propertie name
    this.columns = [
      {
        field: "name",
        header: TRANSLATE("organizationalUnit.table.header.name"), type: FieldTypeEnum.string, order: -1,
      },
      {
        field: "description",
        header: TRANSLATE("organizationalUnit.table.header.description"), type: FieldTypeEnum.string, order: 0,
      },
      {
        field: "creation.when",
        header: TRANSLATE("organizationalUnit.table.header.creation.when"),
        type: FieldTypeEnum.datetime,
        order: 0,
      },
    ];
  }
}
