import {ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output} from "@angular/core";
import {FormBuilder, FormGroup} from "@angular/forms";
import {distinctUntilChanged} from "rxjs/internal/operators/distinctUntilChanged";
import {debounceTime} from "rxjs/operators";

@Component({
  selector: "dlcm-search",
  templateUrl: "./search.component.html",
  styleUrls: ["./search.component.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SearchComponent implements OnInit {
  searchForm: FormGroup;
  search = "search";

  @Input()
  value: string;

  @Output()
  valueEvent: EventEmitter<string>;

  private debounceTime = 600;

  constructor(private fb: FormBuilder) {
    this.valueEvent = new EventEmitter<string>();
  }

  ngOnInit() {
    this.searchForm = this.fb.group({
      search: this.value === null || this.value === undefined ? "" : this.value,
    });

    this.searchForm.get(this.search).valueChanges.pipe(
      debounceTime(this.debounceTime),
      distinctUntilChanged(),
    ).subscribe((value: string) => {
      this.valueEvent.emit(value.trim().toLocaleLowerCase());
    });
  }

}
