import {Inject, OnInit} from "@angular/core";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material";
import {CrudStateModel} from "@app/shared/crud.state";
import {BaseDirective} from "@app/shared/directives/base.directive";
import {DeleteDialogModel} from "@app/shared/models/delete-dialog.model";
import {CrudActionUtil} from "@app/shared/utils/crud-action.util";
import {Store} from "@ngxs/store";

export abstract class AbstractDeleteDialog<T, U extends CrudStateModel<T>> extends BaseDirective implements OnInit {
  paramMessage = {name: ""};

  public abstract readonly KEY_TITLE: string;
  public abstract readonly KEY_MESSAGE: string;
  public abstract readonly KEY_CONFIRM_BUTTON: string;
  public abstract readonly KEY_CANCEL_BUTTON: string;

  protected constructor(protected store: Store,
                        protected dialogRef: MatDialogRef<AbstractDeleteDialog<T, U>>,
                        @Inject(MAT_DIALOG_DATA) public data: DeleteDialogModel,
                        protected state) {
    super();
  }

  ngOnInit() {
    this.paramMessage.name = this.data.name;
  }

  confirm() {
    this.store.dispatch(CrudActionUtil.delete(this.state, this.data.resId));
    this.dialogRef.close();
  }
}
