import {LanguagesModel} from "@app/generated-api";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {StringUtil} from "@app/shared/utils/string.util";

const state = StateEnum.language;

export class LanguageChangeQueryParameters extends ChangeQueryParametersCrud {
  static readonly type = StringUtil.format(ChangeQueryParametersCrud.abstractType, state);

  constructor(public queryParameters: QueryParametersModel) {
    super(queryParameters);
  }
}

export class LanguageGetAll extends GetAllCrud {
  static readonly type = StringUtil.format(GetAllCrud.abstractType, state);

  constructor(public queryParameters?: QueryParametersModel) {
    super(queryParameters);
  }
}

export class LanguageGetAllSuccess extends GetAllSuccessCrud<LanguagesModel> {
  static readonly type = StringUtil.format(GetAllSuccessCrud.abstractType, state);

  constructor(public list: CollectionTypedModel<LanguagesModel>) {
    super(list);
  }
}

export class LanguageGetAllFail extends GetAllFailCrud {
  static readonly type = StringUtil.format(GetAllFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageGetById extends GetByIdCrud {
  static readonly type = StringUtil.format(GetByIdCrud.abstractType, state);

  constructor(public id: string) {
    super(id);
  }
}

export class LanguageGetByIdSuccess extends GetByIdSuccessCrud<LanguagesModel> {
  static readonly type = StringUtil.format(GetByIdSuccessCrud.abstractType, state);

  constructor(public model: LanguagesModel) {
    super(model);
  }
}

export class LanguageGetByIdFail extends GetByIdFailCrud {
  static readonly type = StringUtil.format(GetByIdFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageCreate extends CreateCrud<LanguagesModel> {
  static readonly type = StringUtil.format(CreateCrud.abstractType, state);

  constructor(public model: LanguagesModel) {
    super(model);
  }
}

export class LanguageCreateSuccess extends CreateSuccessCrud {
  static readonly type = StringUtil.format(CreateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageCreateFail extends CreateFailCrud {
  static readonly type = StringUtil.format(CreateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageUpdate extends UpdateCrud<LanguagesModel> {
  static readonly type = StringUtil.format(UpdateCrud.abstractType, state);

  constructor(public model: LanguagesModel) {
    super(model);
  }
}

export class LanguageUpdateSuccess extends UpdateSuccessCrud {
  static readonly type = StringUtil.format(UpdateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageUpdateFail extends UpdateFailCrud {
  static readonly type = StringUtil.format(UpdateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageDelete extends DeleteCrud {
  static readonly type = StringUtil.format(DeleteCrud.abstractType, state);

  constructor(public resId: string) {
    super(resId);
  }
}

export class LanguageDeleteSuccess extends DeleteSuccessCrud {
  static readonly type = StringUtil.format(DeleteSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LanguageDeleteFail extends DeleteFailCrud {
  static readonly type = StringUtil.format(DeleteFailCrud.abstractType, state);

  constructor() {
    super();
  }
}
