import {LanguagesModel} from "@app/generated-api";
import {CrudState, CrudStateModel} from "@app/shared/crud.state";
import {AdminResourceApiEnum} from "@app/shared/enums/api.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {
  LanguageChangeQueryParameters,
  LanguageCreate,
  LanguageCreateFail,
  LanguageCreateSuccess,
  LanguageDelete,
  LanguageDeleteFail,
  LanguageDeleteSuccess,
  LanguageGetAll,
  LanguageGetAllFail,
  LanguageGetAllSuccess,
  LanguageGetById,
  LanguageGetByIdFail,
  LanguageGetByIdSuccess,
  LanguageUpdate,
  LanguageUpdateFail,
  LanguageUpdateSuccess,
} from "@app/shared/language.action";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {ApiService} from "@app/shared/services/api.service";
import {Action, State, StateContext} from "@ngxs/store";
import {Observable} from "rxjs";

export interface LanguageStateModel extends CrudStateModel<LanguagesModel> {
}

@State<LanguageStateModel>({
  name: StateEnum.language,
  defaults: {
    total: 0,
    isLoading: false,
    list: [],
    current: null,
    queryParameters: new QueryParametersModel(),
  },
})
export class LanguageState extends CrudState<LanguagesModel> {
  protected urlResource: string;
  protected state: StateEnum;

  constructor(protected apiService: ApiService) {
    super(apiService);
    this.state = StateEnum.language;
    this.urlResource = AdminResourceApiEnum.languages;
  }

  @Action(LanguageChangeQueryParameters)
  changeQueryParameters(ctx: StateContext<LanguageStateModel>, action: LanguageChangeQueryParameters): void {
    super.changeQueryParameters(ctx, action);
  }

  @Action(LanguageGetAll, {cancelUncompleted: true})
  getAll(ctx: StateContext<LanguageStateModel>, action: LanguageGetAll) {
    return super.getAll(ctx, action);
  }

  @Action(LanguageGetAllSuccess)
  getAllSuccess(ctx: StateContext<LanguageStateModel>, action: LanguageGetAllSuccess): void {
    super.getAllSuccess(ctx, action);
  }

  @Action(LanguageGetAllFail)
  getAllFail(ctx: StateContext<LanguageStateModel>, action: LanguageGetAllFail): void {
    super.getAllFail(ctx, action);
  }

  @Action(LanguageGetById, {cancelUncompleted: true})
  getById(ctx: StateContext<LanguageStateModel>, action: LanguageGetById): Observable<LanguagesModel> {
    return super.getById(ctx, action);
  }

  @Action(LanguageGetByIdSuccess)
  getByIdSuccess(ctx: StateContext<LanguageStateModel>, action: LanguageGetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
  }

  @Action(LanguageGetByIdFail)
  getByIdFail(ctx: StateContext<LanguageStateModel>, action: LanguageGetByIdFail): void {
    super.getByIdFail(ctx, action);
  }

  @Action(LanguageCreate, {cancelUncompleted: true})
  create(ctx: StateContext<LanguageStateModel>, action: LanguageCreate): Observable<LanguagesModel> {
    return super.create(ctx, action);
  }

  @Action(LanguageCreateSuccess)
  createSuccess(ctx: StateContext<LanguageStateModel>, action: LanguageCreateSuccess): void {
    super.createSuccess(ctx, action);
  }

  @Action(LanguageCreateFail)
  createFail(ctx: StateContext<LanguageStateModel>, action: LanguageCreateFail): void {
    super.createFail(ctx, action);
  }

  @Action(LanguageUpdate, {cancelUncompleted: true})
  update(ctx: StateContext<LanguageStateModel>, action: LanguageUpdate): Observable<LanguagesModel> {
    return super.update(ctx, action);
  }

  @Action(LanguageUpdateSuccess)
  updateSuccess(ctx: StateContext<LanguageStateModel>, action: LanguageUpdateSuccess): void {
    super.updateSuccess(ctx, action);
  }

  @Action(LanguageUpdateFail)
  updateFail(ctx: StateContext<LanguageStateModel>, action: LanguageUpdateFail): void {
    super.updateFail(ctx, action);
  }

  @Action(LanguageDelete, {cancelUncompleted: true})
  delete(ctx: StateContext<LanguageStateModel>, action: LanguageDelete): Observable<LanguagesModel> {
    return super.delete(ctx, action);
  }

  @Action(LanguageDeleteSuccess)
  deleteSuccess(ctx: StateContext<LanguageStateModel>, action: LanguageDeleteSuccess): void {
    super.deleteSuccess(ctx, action);
  }

  @Action(LanguageDeleteFail)
  deleteFail(ctx: StateContext<LanguageStateModel>, action: LanguageDeleteFail): void {
    super.deleteFail(ctx, action);
  }
}
