import {LicensesModel} from "@app/generated-api";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {StringUtil} from "@app/shared/utils/string.util";

const state = StateEnum.license;

export class LicenseChangeQueryParameters extends ChangeQueryParametersCrud {
  static readonly type = StringUtil.format(ChangeQueryParametersCrud.abstractType, state);

  constructor(public queryParameters: QueryParametersModel) {
    super(queryParameters);
  }
}

export class LicenseGetAll extends GetAllCrud {
  static readonly type = StringUtil.format(GetAllCrud.abstractType, state);

  constructor(public queryParameters?: QueryParametersModel) {
    super(queryParameters);
  }
}

export class LicenseGetAllSuccess extends GetAllSuccessCrud<LicensesModel> {
  static readonly type = StringUtil.format(GetAllSuccessCrud.abstractType, state);

  constructor(public list: CollectionTypedModel<LicensesModel>) {
    super(list);
  }
}

export class LicenseGetAllFail extends GetAllFailCrud {
  static readonly type = StringUtil.format(GetAllFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseGetById extends GetByIdCrud {
  static readonly type = StringUtil.format(GetByIdCrud.abstractType, state);

  constructor(public id: string) {
    super(id);
  }
}

export class LicenseGetByIdSuccess extends GetByIdSuccessCrud<LicensesModel> {
  static readonly type = StringUtil.format(GetByIdSuccessCrud.abstractType, state);

  constructor(public model: LicensesModel) {
    super(model);
  }
}

export class LicenseGetByIdFail extends GetByIdFailCrud {
  static readonly type = StringUtil.format(GetByIdFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseCreate extends CreateCrud<LicensesModel> {
  static readonly type = StringUtil.format(CreateCrud.abstractType, state);

  constructor(public model: LicensesModel) {
    super(model);
  }
}

export class LicenseCreateSuccess extends CreateSuccessCrud {
  static readonly type = StringUtil.format(CreateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseCreateFail extends CreateFailCrud {
  static readonly type = StringUtil.format(CreateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseUpdate extends UpdateCrud<LicensesModel> {
  static readonly type = StringUtil.format(UpdateCrud.abstractType, state);

  constructor(public model: LicensesModel) {
    super(model);
  }
}

export class LicenseUpdateSuccess extends UpdateSuccessCrud {
  static readonly type = StringUtil.format(UpdateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseUpdateFail extends UpdateFailCrud {
  static readonly type = StringUtil.format(UpdateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseDelete extends DeleteCrud {
  static readonly type = StringUtil.format(DeleteCrud.abstractType, state);

  constructor(public resId: string) {
    super(resId);
  }
}

export class LicenseDeleteSuccess extends DeleteSuccessCrud {
  static readonly type = StringUtil.format(DeleteSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class LicenseDeleteFail extends DeleteFailCrud {
  static readonly type = StringUtil.format(DeleteFailCrud.abstractType, state);

  constructor() {
    super();
  }
}
