import {LicensesModel} from "@app/generated-api";
import {CrudState, CrudStateModel} from "@app/shared/crud.state";
import {AdminResourceApiEnum} from "@app/shared/enums/api.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {
  LicenseChangeQueryParameters,
  LicenseCreate,
  LicenseCreateFail,
  LicenseCreateSuccess,
  LicenseDelete,
  LicenseDeleteFail,
  LicenseDeleteSuccess,
  LicenseGetAll,
  LicenseGetAllFail,
  LicenseGetAllSuccess,
  LicenseGetById,
  LicenseGetByIdFail,
  LicenseGetByIdSuccess,
  LicenseUpdate,
  LicenseUpdateFail,
  LicenseUpdateSuccess,
} from "@app/shared/license.action";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {ApiService} from "@app/shared/services/api.service";
import {Action, State, StateContext} from "@ngxs/store";
import {Observable} from "rxjs";

export interface LicenseStateModel extends CrudStateModel<LicensesModel> {
}

@State<LicenseStateModel>({
  name: StateEnum.license,
  defaults: {
    total: 0,
    isLoading: false,
    list: [],
    current: null,
    queryParameters: new QueryParametersModel(),
  },
})
export class LicenseState extends CrudState<LicensesModel> {
  protected urlResource: string;
  protected state: StateEnum;

  constructor(protected apiService: ApiService) {
    super(apiService);
    this.state = StateEnum.license;
    this.urlResource = AdminResourceApiEnum.licenses;
  }

  @Action(LicenseChangeQueryParameters)
  changeQueryParameters(ctx: StateContext<LicenseStateModel>, action: LicenseChangeQueryParameters): void {
    super.changeQueryParameters(ctx, action);
  }

  @Action(LicenseGetAll, {cancelUncompleted: true})
  getAll(ctx: StateContext<LicenseStateModel>, action: LicenseGetAll) {
    return super.getAll(ctx, action);
  }

  @Action(LicenseGetAllSuccess)
  getAllSuccess(ctx: StateContext<LicenseStateModel>, action: LicenseGetAllSuccess): void {
    super.getAllSuccess(ctx, action);
  }

  @Action(LicenseGetAllFail)
  getAllFail(ctx: StateContext<LicenseStateModel>, action: LicenseGetAllFail): void {
    super.getAllFail(ctx, action);
  }

  @Action(LicenseGetById, {cancelUncompleted: true})
  getById(ctx: StateContext<LicenseStateModel>, action: LicenseGetById): Observable<LicensesModel> {
    return super.getById(ctx, action);
  }

  @Action(LicenseGetByIdSuccess)
  getByIdSuccess(ctx: StateContext<LicenseStateModel>, action: LicenseGetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
  }

  @Action(LicenseGetByIdFail)
  getByIdFail(ctx: StateContext<LicenseStateModel>, action: LicenseGetByIdFail): void {
    super.getByIdFail(ctx, action);
  }

  @Action(LicenseCreate, {cancelUncompleted: true})
  create(ctx: StateContext<LicenseStateModel>, action: LicenseCreate): Observable<LicensesModel> {
    return super.create(ctx, action);
  }

  @Action(LicenseCreateSuccess)
  createSuccess(ctx: StateContext<LicenseStateModel>, action: LicenseCreateSuccess): void {
    super.createSuccess(ctx, action);
  }

  @Action(LicenseCreateFail)
  createFail(ctx: StateContext<LicenseStateModel>, action: LicenseCreateFail): void {
    super.createFail(ctx, action);
  }

  @Action(LicenseUpdate, {cancelUncompleted: true})
  update(ctx: StateContext<LicenseStateModel>, action: LicenseUpdate): Observable<LicensesModel> {
    return super.update(ctx, action);
  }

  @Action(LicenseUpdateSuccess)
  updateSuccess(ctx: StateContext<LicenseStateModel>, action: LicenseUpdateSuccess): void {
    super.updateSuccess(ctx, action);
  }

  @Action(LicenseUpdateFail)
  updateFail(ctx: StateContext<LicenseStateModel>, action: LicenseUpdateFail): void {
    super.updateFail(ctx, action);
  }

  @Action(LicenseDelete, {cancelUncompleted: true})
  delete(ctx: StateContext<LicenseStateModel>, action: LicenseDelete): Observable<LicensesModel> {
    return super.delete(ctx, action);
  }

  @Action(LicenseDeleteSuccess)
  deleteSuccess(ctx: StateContext<LicenseStateModel>, action: LicenseDeleteSuccess): void {
    super.deleteSuccess(ctx, action);
  }

  @Action(LicenseDeleteFail)
  deleteFail(ctx: StateContext<LicenseStateModel>, action: LicenseDeleteFail): void {
    super.deleteFail(ctx, action);
  }
}
