import {OrganizationalUnitsModel} from "@app/generated-api";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {StringUtil} from "@app/shared/utils/string.util";

const state = StateEnum.organizationalUnit;

export class OrgUnitChangeQueryParameters extends ChangeQueryParametersCrud {
  static readonly type = StringUtil.format(ChangeQueryParametersCrud.abstractType, state);

  constructor(public queryParameters: QueryParametersModel) {
    super(queryParameters);
  }
}

export class OrgUnitGetAll extends GetAllCrud {
  static readonly type = StringUtil.format(GetAllCrud.abstractType, state);

  constructor(public queryParameters?: QueryParametersModel) {
    super(queryParameters);
  }
}

export class OrgUnitGetAllSuccess extends GetAllSuccessCrud<OrganizationalUnitsModel> {
  static readonly type = StringUtil.format(GetAllSuccessCrud.abstractType, state);

  constructor(public list: CollectionTypedModel<OrganizationalUnitsModel>) {
    super(list);
  }
}

export class OrgUnitGetAllFail extends GetAllFailCrud {
  static readonly type = StringUtil.format(GetAllFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitGetById extends GetByIdCrud {
  static readonly type = StringUtil.format(GetByIdCrud.abstractType, state);

  constructor(public id: string) {
    super(id);
  }
}

export class OrgUnitGetByIdSuccess extends GetByIdSuccessCrud<OrganizationalUnitsModel> {
  static readonly type = StringUtil.format(GetByIdSuccessCrud.abstractType, state);

  constructor(public model: OrganizationalUnitsModel) {
    super(model);
  }
}

export class OrgUnitGetByIdFail extends GetByIdFailCrud {
  static readonly type = StringUtil.format(GetByIdFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitCreate extends CreateCrud<OrganizationalUnitsModel> {
  static readonly type = StringUtil.format(CreateCrud.abstractType, state);

  constructor(public model: OrganizationalUnitsModel) {
    super(model);
  }
}

export class OrgUnitCreateSuccess extends CreateSuccessCrud {
  static readonly type = StringUtil.format(CreateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitCreateFail extends CreateFailCrud {
  static readonly type = StringUtil.format(CreateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitUpdate extends UpdateCrud<OrganizationalUnitsModel> {
  static readonly type = StringUtil.format(UpdateCrud.abstractType, state);

  constructor(public model: OrganizationalUnitsModel) {
    super(model);
  }
}

export class OrgUnitUpdateSuccess extends UpdateSuccessCrud {
  static readonly type = StringUtil.format(UpdateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitUpdateFail extends UpdateFailCrud {
  static readonly type = StringUtil.format(UpdateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitDelete extends DeleteCrud {
  static readonly type = StringUtil.format(DeleteCrud.abstractType, state);

  constructor(public resId: string) {
    super(resId);
  }
}

export class OrgUnitDeleteSuccess extends DeleteSuccessCrud {
  static readonly type = StringUtil.format(DeleteSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class OrgUnitDeleteFail extends DeleteFailCrud {
  static readonly type = StringUtil.format(DeleteFailCrud.abstractType, state);

  constructor() {
    super();
  }
}
