import {OrganizationalUnitsModel} from "@app/generated-api";
import {CrudState, CrudStateModel} from "@app/shared/crud.state";
import {AdminResourceApiEnum} from "@app/shared/enums/api.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {
  OrgUnitChangeQueryParameters,
  OrgUnitCreate,
  OrgUnitCreateFail,
  OrgUnitCreateSuccess,
  OrgUnitDelete,
  OrgUnitDeleteFail,
  OrgUnitDeleteSuccess,
  OrgUnitGetAll,
  OrgUnitGetAllFail,
  OrgUnitGetAllSuccess,
  OrgUnitGetById,
  OrgUnitGetByIdFail,
  OrgUnitGetByIdSuccess,
  OrgUnitUpdate,
  OrgUnitUpdateFail,
  OrgUnitUpdateSuccess,
} from "@app/shared/organizational-unit.action";
import {ApiService} from "@app/shared/services/api.service";
import {Action, State, StateContext} from "@ngxs/store";
import {Observable} from "rxjs";

export interface OrganizationalUnitStateModel extends CrudStateModel<OrganizationalUnitsModel> {
}

const DEFAULT_PAGE_SIZE = 20;

@State<OrganizationalUnitStateModel>({
  name: StateEnum.organizationalUnit,
  defaults: {
    total: 0,
    isLoading: false,
    list: [],
    current: null,
    queryParameters: new QueryParametersModel(DEFAULT_PAGE_SIZE),
  },
})
export class OrganizationalUnitState extends CrudState<OrganizationalUnitsModel> {
  protected urlResource: string;
  protected state: StateEnum;

  constructor(protected apiService: ApiService) {
    super(apiService);
    this.state = StateEnum.organizationalUnit;
    this.urlResource = AdminResourceApiEnum.organizationalUnits;
  }

  @Action(OrgUnitChangeQueryParameters)
  changeQueryParameters(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitChangeQueryParameters): void {
    super.changeQueryParameters(ctx, action);
  }

  @Action(OrgUnitGetAll, {cancelUncompleted: true})
  getAll(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetAll): Observable<CollectionTypedModel<OrganizationalUnitsModel>> {
    return super.getAll(ctx, action);
  }

  @Action(OrgUnitGetAllSuccess)
  getAllSuccess(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetAllSuccess): void {
    super.getAllSuccess(ctx, action);
  }

  @Action(OrgUnitGetAllFail)
  getAllFail(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetAllFail): void {
    super.getAllFail(ctx, action);
  }

  @Action(OrgUnitGetById, {cancelUncompleted: true})
  getById(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetById): Observable<OrganizationalUnitsModel> {
    return super.getById(ctx, action);
  }

  @Action(OrgUnitGetByIdSuccess)
  getByIdSuccess(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
  }

  @Action(OrgUnitGetByIdFail)
  getByIdFail(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitGetByIdFail): void {
    super.getByIdFail(ctx, action);
  }

  @Action(OrgUnitCreate, {cancelUncompleted: true})
  create(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitCreate): Observable<OrganizationalUnitsModel> {
    return super.create(ctx, action);
  }

  @Action(OrgUnitCreateSuccess)
  createSuccess(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitCreateSuccess): void {
    super.createSuccess(ctx, action);
  }

  @Action(OrgUnitCreateFail)
  createFail(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitCreateFail): void {
    super.createFail(ctx, action);
  }

  @Action(OrgUnitUpdate, {cancelUncompleted: true})
  update(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitUpdate): Observable<OrganizationalUnitsModel> {
    return super.update(ctx, action);
  }

  @Action(OrgUnitUpdateSuccess)
  updateSuccess(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitUpdateSuccess): void {
    super.updateSuccess(ctx, action);
  }

  @Action(OrgUnitUpdateFail)
  updateFail(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitUpdateFail): void {
    super.updateFail(ctx, action);
  }

  @Action(OrgUnitDelete, {cancelUncompleted: true})
  delete(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitDelete): Observable<OrganizationalUnitsModel> {
    return super.delete(ctx, action);
  }

  @Action(OrgUnitDeleteSuccess)
  deleteSuccess(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitDeleteSuccess): void {
    super.deleteSuccess(ctx, action);
  }

  @Action(OrgUnitDeleteFail)
  deleteFail(ctx: StateContext<OrganizationalUnitStateModel>, action: OrgUnitDeleteFail): void {
    super.deleteFail(ctx, action);
  }
}
