import {PreservationPoliciesModel} from "@app/generated-api";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {StringUtil} from "@app/shared/utils/string.util";

const state = StateEnum.preservationPolicy;

export class PreservationPolicyChangeQueryParameters extends ChangeQueryParametersCrud {
  static readonly type = StringUtil.format(ChangeQueryParametersCrud.abstractType, state);

  constructor(public queryParameters: QueryParametersModel) {
    super(queryParameters);
  }
}

export class PreservationPolicyGetAll extends GetAllCrud {
  static readonly type = StringUtil.format(GetAllCrud.abstractType, state);

  constructor(public queryParameters?: QueryParametersModel) {
    super(queryParameters);
  }
}

export class PreservationPolicyGetAllSuccess extends GetAllSuccessCrud<PreservationPoliciesModel> {
  static readonly type = StringUtil.format(GetAllSuccessCrud.abstractType, state);

  constructor(public list: CollectionTypedModel<PreservationPoliciesModel>) {
    super(list);
  }
}

export class PreservationPolicyGetAllFail extends GetAllFailCrud {
  static readonly type = StringUtil.format(GetAllFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyGetById extends GetByIdCrud {
  static readonly type = StringUtil.format(GetByIdCrud.abstractType, state);

  constructor(public id: string) {
    super(id);
  }
}

export class PreservationPolicyGetByIdSuccess extends GetByIdSuccessCrud<PreservationPoliciesModel> {
  static readonly type = StringUtil.format(GetByIdSuccessCrud.abstractType, state);

  constructor(public model: PreservationPoliciesModel) {
    super(model);
  }
}

export class PreservationPolicyGetByIdFail extends GetByIdFailCrud {
  static readonly type = StringUtil.format(GetByIdFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyCreate extends CreateCrud<PreservationPoliciesModel> {
  static readonly type = StringUtil.format(CreateCrud.abstractType, state);

  constructor(public model: PreservationPoliciesModel) {
    super(model);
  }
}

export class PreservationPolicyCreateSuccess extends CreateSuccessCrud {
  static readonly type = StringUtil.format(CreateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyCreateFail extends CreateFailCrud {
  static readonly type = StringUtil.format(CreateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyUpdate extends UpdateCrud<PreservationPoliciesModel> {
  static readonly type = StringUtil.format(UpdateCrud.abstractType, state);

  constructor(public model: PreservationPoliciesModel) {
    super(model);
  }
}

export class PreservationPolicyUpdateSuccess extends UpdateSuccessCrud {
  static readonly type = StringUtil.format(UpdateSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyUpdateFail extends UpdateFailCrud {
  static readonly type = StringUtil.format(UpdateFailCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyDelete extends DeleteCrud {
  static readonly type = StringUtil.format(DeleteCrud.abstractType, state);

  constructor(public resId: string) {
    super(resId);
  }
}

export class PreservationPolicyDeleteSuccess extends DeleteSuccessCrud {
  static readonly type = StringUtil.format(DeleteSuccessCrud.abstractType, state);

  constructor() {
    super();
  }
}

export class PreservationPolicyDeleteFail extends DeleteFailCrud {
  static readonly type = StringUtil.format(DeleteFailCrud.abstractType, state);

  constructor() {
    super();
  }
}
