import {PreservationPoliciesModel} from "@app/generated-api";
import {CrudState, CrudStateModel} from "@app/shared/crud.state";
import {AdminResourceApiEnum} from "@app/shared/enums/api.enum";
import {StateEnum} from "@app/shared/enums/state.enum";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {
  PreservationPolicyChangeQueryParameters,
  PreservationPolicyCreate,
  PreservationPolicyCreateFail,
  PreservationPolicyCreateSuccess,
  PreservationPolicyDelete,
  PreservationPolicyDeleteFail,
  PreservationPolicyDeleteSuccess,
  PreservationPolicyGetAll,
  PreservationPolicyGetAllFail,
  PreservationPolicyGetAllSuccess,
  PreservationPolicyGetById,
  PreservationPolicyGetByIdFail,
  PreservationPolicyGetByIdSuccess,
  PreservationPolicyUpdate,
  PreservationPolicyUpdateFail,
  PreservationPolicyUpdateSuccess,
} from "@app/shared/preservation-policy.action";
import {ApiService} from "@app/shared/services/api.service";
import {Action, State, StateContext} from "@ngxs/store";
import {Observable} from "rxjs";

export interface PreservationPolicyStateModel extends CrudStateModel<PreservationPoliciesModel> {
}

@State<PreservationPolicyStateModel>({
  name: StateEnum.preservationPolicy,
  defaults: {
    total: 0,
    isLoading: false,
    list: [],
    current: null,
    queryParameters: new QueryParametersModel(),
  },
})
export class PreservationPolicyState extends CrudState<PreservationPoliciesModel> {
  protected urlResource: string;
  protected state: StateEnum;

  constructor(protected apiService: ApiService) {
    super(apiService);
    this.state = StateEnum.preservationPolicy;
    this.urlResource = AdminResourceApiEnum.preservationPolicies;
  }

  @Action(PreservationPolicyChangeQueryParameters)
  changeQueryParameters(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyChangeQueryParameters): void {
    super.changeQueryParameters(ctx, action);
  }

  @Action(PreservationPolicyGetAll, {cancelUncompleted: true})
  getAll(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetAll) {
    return super.getAll(ctx, action);
  }

  @Action(PreservationPolicyGetAllSuccess)
  getAllSuccess(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetAllSuccess): void {
    super.getAllSuccess(ctx, action);
  }

  @Action(PreservationPolicyGetAllFail)
  getAllFail(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetAllFail): void {
    super.getAllFail(ctx, action);
  }

  @Action(PreservationPolicyGetById, {cancelUncompleted: true})
  getById(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetById): Observable<PreservationPoliciesModel> {
    return super.getById(ctx, action);
  }

  @Action(PreservationPolicyGetByIdSuccess)
  getByIdSuccess(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
  }

  @Action(PreservationPolicyGetByIdFail)
  getByIdFail(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyGetByIdFail): void {
    super.getByIdFail(ctx, action);
  }

  @Action(PreservationPolicyCreate, {cancelUncompleted: true})
  create(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyCreate): Observable<PreservationPoliciesModel> {
    return super.create(ctx, action);
  }

  @Action(PreservationPolicyCreateSuccess)
  createSuccess(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyCreateSuccess): void {
    super.createSuccess(ctx, action);
  }

  @Action(PreservationPolicyCreateFail)
  createFail(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyCreateFail): void {
    super.createFail(ctx, action);
  }

  @Action(PreservationPolicyUpdate, {cancelUncompleted: true})
  update(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyUpdate): Observable<PreservationPoliciesModel> {
    return super.update(ctx, action);
  }

  @Action(PreservationPolicyUpdateSuccess)
  updateSuccess(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyUpdateSuccess): void {
    super.updateSuccess(ctx, action);
  }

  @Action(PreservationPolicyUpdateFail)
  updateFail(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyUpdateFail): void {
    super.updateFail(ctx, action);
  }

  @Action(PreservationPolicyDelete, {cancelUncompleted: true})
  delete(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyDelete): Observable<PreservationPoliciesModel> {
    return super.delete(ctx, action);
  }

  @Action(PreservationPolicyDeleteSuccess)
  deleteSuccess(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyDeleteSuccess): void {
    super.deleteSuccess(ctx, action);
  }

  @Action(PreservationPolicyDeleteFail)
  deleteFail(ctx: StateContext<PreservationPolicyStateModel>, action: PreservationPolicyDeleteFail): void {
    super.deleteFail(ctx, action);
  }
}
