import {CommonModule} from "@angular/common";
import {NgModule} from "@angular/core";
import {FormsModule, ReactiveFormsModule} from "@angular/forms";
import {MaterialModule} from "@app/material.module";
import {DataTableComponent} from "@app/shared/components/data-table/data-table.component";
import {SearchComponent} from "@app/shared/components/search/search.component";
import {LanguageState} from "@app/shared/language.state";
import {LicenseState} from "@app/shared/license.state";
import {OrganizationalUnitState} from "@app/shared/organizational-unit.state";
import {PreservationPolicyState} from "@app/shared/preservation-policy.state";
import {ApiService} from "@app/shared/services/api.service";
import {AuthGuardService} from "@app/shared/services/auth-guard.service";
import {ClickEventService} from "@app/shared/services/clickevent.service";
import {SharedState} from "@app/shared/shared.state";
import {SubmissionPolicyState} from "@app/shared/submission-policy.state";
import {FontAwesomeModule} from "@fortawesome/angular-fontawesome";
import {library} from "@fortawesome/fontawesome-svg-core";
import {fas} from "@fortawesome/free-solid-svg-icons";
import {TranslateModule} from "@ngx-translate/core";
import {NgxsModule} from "@ngxs/store";
import {TableModule} from "primeng/table";
import {BreadcrumbComponent} from "./components/breadcrumb/breadcrumb.component";
import {PaginatorComponent} from "./components/paginator/paginator.component";

const views = [];
const dialogs = [];
const components = [
  SearchComponent,
  DataTableComponent,
  PaginatorComponent,
  BreadcrumbComponent,
];
const directives = [];
const modules = [
  CommonModule,
  FormsModule,
  ReactiveFormsModule,
  MaterialModule,
  FontAwesomeModule,
  TableModule,
  TranslateModule,
];

@NgModule({
  declarations: [
    ...views,
    ...dialogs,
    ...components,
    ...directives,
  ],
  imports: [
    ...modules,
    NgxsModule.forFeature([
      SharedState,
      LicenseState,
      LanguageState,
      PreservationPolicyState,
      SubmissionPolicyState,
      OrganizationalUnitState,
    ]),
  ],
  exports: [
    ...modules,
    ...views,
    ...dialogs,
    ...components,
    ...directives,
  ],
  providers: [
    ClickEventService,
    ApiService,
    AuthGuardService,
  ],
})
export class SharedModule {
}

// Fontawesome library
library.add(fas);
