import {BaseStateModel} from "@app/base.state";
import {StateEnum} from "@app/shared/enums/state.enum";
import {LanguageGetAll} from "@app/shared/language.action";
import {LanguageState, LanguageStateModel} from "@app/shared/language.state";
import {LicenseGetAll} from "@app/shared/license.action";
import {LicenseState, LicenseStateModel} from "@app/shared/license.state";
import {PreservationPolicyGetAll} from "@app/shared/preservation-policy.action";
import {PreservationPolicyState, PreservationPolicyStateModel} from "@app/shared/preservation-policy.state";
import {GetAllResources, GetAllResourcesFail, GetAllResourcesSuccess} from "@app/shared/shared.action";
import {SubmissionPolicyGetAll} from "@app/shared/submission-policy.action";
import {SubmissionPolicyState, SubmissionPolicyStateModel} from "@app/shared/submission-policy.state";
import {Action, State, StateContext} from "@ngxs/store";

export interface SharedStateModel extends BaseStateModel {
  language: LanguageStateModel;
  license: LicenseStateModel;
  submissionPolicy: SubmissionPolicyStateModel;
  preservationPolicy: PreservationPolicyStateModel;
}

@State<SharedStateModel>({
  name: StateEnum.shared,
  defaults: {
    isLoading: false,
    language: null,
    license: null,
    preservationPolicy: null,
    submissionPolicy: null,
  },
  children: [
    LanguageState,
    LicenseState,
    SubmissionPolicyState,
    PreservationPolicyState,
  ],
})
export class SharedState {
  constructor() {
  }

  @Action(GetAllResources, {cancelUncompleted: true})
  getAllResources(ctx: StateContext<SharedStateModel>, action: GetAllResources) {
    ctx.patchState({
      isLoading: true,
    });

    ctx.dispatch([
      new LanguageGetAll(),
      new LicenseGetAll(),
      new PreservationPolicyGetAll(),
      new SubmissionPolicyGetAll(),
      new GetAllResourcesSuccess(), // TO FIX Should be raised only when GetAllLanguagesSuccess and GetAllLicensesSuccess is raised)
    ]);
  }

  @Action(GetAllResourcesSuccess)
  getAllResourcesSuccess(ctx: StateContext<SharedStateModel>, action: GetAllResourcesSuccess) {
    ctx.patchState({
      isLoading: false,
    });
  }

  @Action(GetAllResourcesFail)
  getAllResourcesFail(ctx: StateContext<SharedStateModel>) {
    ctx.patchState({
      isLoading: false,
    });
  }
}



