import {
  DepositChangeQueryParameters,
  DepositCreate,
  DepositCreateFail,
  DepositCreateSuccess,
  DepositDelete,
  DepositDeleteFail,
  DepositDeleteSuccess,
  DepositGetAll,
  DepositGetAllFail,
  DepositGetAllSuccess,
  DepositGetById,
  DepositGetByIdFail,
  DepositGetByIdSuccess,
  DepositUpdate,
  DepositUpdateFail,
  DepositUpdateSuccess,
} from "@app/deposit/deposit.action";
import {
  OrgUnitChangeQueryParameters,
  OrgUnitCreate,
  OrgUnitCreateFail,
  OrgUnitCreateSuccess,
  OrgUnitDelete,
  OrgUnitDeleteFail,
  OrgUnitDeleteSuccess,
  OrgUnitGetAll,
  OrgUnitGetAllFail,
  OrgUnitGetAllSuccess,
  OrgUnitGetById,
  OrgUnitGetByIdFail,
  OrgUnitGetByIdSuccess,
  OrgUnitUpdate,
  OrgUnitUpdateFail,
  OrgUnitUpdateSuccess,
} from "@app/shared/organizational-unit.action";
import {
  ChangeQueryParametersCrud,
  CreateCrud,
  CreateFailCrud,
  CreateSuccessCrud,
  DeleteCrud,
  DeleteFailCrud,
  DeleteSuccessCrud,
  GetAllCrud,
  GetAllFailCrud,
  GetAllSuccessCrud,
  GetByIdCrud,
  GetByIdFailCrud,
  GetByIdSuccessCrud,
  UpdateCrud,
  UpdateFailCrud,
  UpdateSuccessCrud,
} from "@app/shared/crud.action";
import {StateEnum} from "@app/shared/enums/state.enum";
import {
  LanguageChangeQueryParameters,
  LanguageCreate,
  LanguageCreateFail,
  LanguageCreateSuccess,
  LanguageDelete,
  LanguageDeleteFail,
  LanguageDeleteSuccess,
  LanguageGetAll,
  LanguageGetAllFail,
  LanguageGetAllSuccess,
  LanguageGetById,
  LanguageGetByIdFail,
  LanguageGetByIdSuccess,
  LanguageUpdate,
  LanguageUpdateFail,
  LanguageUpdateSuccess,
} from "@app/shared/language.action";
import {
  LicenseChangeQueryParameters,
  LicenseCreate,
  LicenseCreateFail,
  LicenseCreateSuccess,
  LicenseDelete,
  LicenseDeleteFail,
  LicenseDeleteSuccess,
  LicenseGetAll,
  LicenseGetAllFail,
  LicenseGetAllSuccess,
  LicenseGetById,
  LicenseGetByIdFail,
  LicenseGetByIdSuccess,
  LicenseUpdate,
  LicenseUpdateFail,
  LicenseUpdateSuccess,
} from "@app/shared/license.action";

import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {
  PreservationPolicyChangeQueryParameters,
  PreservationPolicyCreate,
  PreservationPolicyCreateFail,
  PreservationPolicyCreateSuccess,
  PreservationPolicyDelete,
  PreservationPolicyDeleteFail,
  PreservationPolicyDeleteSuccess,
  PreservationPolicyGetAll,
  PreservationPolicyGetAllFail,
  PreservationPolicyGetAllSuccess,
  PreservationPolicyGetById,
  PreservationPolicyGetByIdFail,
  PreservationPolicyGetByIdSuccess,
  PreservationPolicyUpdate,
  PreservationPolicyUpdateFail,
  PreservationPolicyUpdateSuccess,
} from "@app/shared/preservation-policy.action";
import {
  SubmissionPolicyChangeQueryParameters,
  SubmissionPolicyCreate,
  SubmissionPolicyCreateFail,
  SubmissionPolicyCreateSuccess,
  SubmissionPolicyDelete,
  SubmissionPolicyDeleteFail,
  SubmissionPolicyDeleteSuccess,
  SubmissionPolicyGetAll,
  SubmissionPolicyGetAllFail,
  SubmissionPolicyGetAllSuccess,
  SubmissionPolicyGetById,
  SubmissionPolicyGetByIdFail,
  SubmissionPolicyGetByIdSuccess,
  SubmissionPolicyUpdate,
  SubmissionPolicyUpdateFail,
  SubmissionPolicyUpdateSuccess,
} from "@app/shared/submission-policy.action";
import {StringUtil} from "@app/shared/utils/string.util";

export class CrudActionUtil {
  private static readonly messageNotFound: string = "There is no action declared for the state '{0}'.";

  static changeQueryParameters(state: StateEnum, queryParameters: QueryParametersModel): ChangeQueryParametersCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitChangeQueryParameters(queryParameters);
    }
    if (state === StateEnum.deposit) {
      return new DepositChangeQueryParameters(queryParameters);
    }
    if (state === StateEnum.language) {
      return new LanguageChangeQueryParameters(queryParameters);
    }
    if (state === StateEnum.license) {
      return new LicenseChangeQueryParameters(queryParameters);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyChangeQueryParameters(queryParameters);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyChangeQueryParameters(queryParameters);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getAll(state: StateEnum, queryParameters?: QueryParametersModel): GetAllCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetAll(queryParameters);
    }
    if (state === StateEnum.deposit) {
      return new DepositGetAll(queryParameters);
    }
    if (state === StateEnum.language) {
      return new LanguageGetAll(queryParameters);
    }
    if (state === StateEnum.license) {
      return new LicenseGetAll(queryParameters);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetAll(queryParameters);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetAll(queryParameters);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getAllSuccess<T>(state: StateEnum, list: CollectionTypedModel<T>): GetAllSuccessCrud<any> {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetAllSuccess(list);
    }
    if (state === StateEnum.deposit) {
      return new DepositGetAllSuccess(list);
    }
    if (state === StateEnum.language) {
      return new LanguageGetAllSuccess(list);
    }
    if (state === StateEnum.license) {
      return new LicenseGetAllSuccess(list);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetAllSuccess(list);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetAllSuccess(list);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getAllFail(state: StateEnum): GetAllFailCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetAllFail();
    }
    if (state === StateEnum.deposit) {
      return new DepositGetAllFail();
    }
    if (state === StateEnum.language) {
      return new LanguageGetAllFail();
    }
    if (state === StateEnum.license) {
      return new LicenseGetAllFail();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetAllFail();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetAllFail();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getById(state: StateEnum, id: string): GetByIdCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetById(id);
    }
    if (state === StateEnum.deposit) {
      return new DepositGetById(id);
    }
    if (state === StateEnum.language) {
      return new LanguageGetById(id);
    }
    if (state === StateEnum.license) {
      return new LicenseGetById(id);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetById(id);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetById(id);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getByIdSuccess<T>(state: StateEnum, model: T): GetByIdSuccessCrud<any> {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetByIdSuccess(model);
    }
    if (state === StateEnum.deposit) {
      return new DepositGetByIdSuccess(model);
    }
    if (state === StateEnum.language) {
      return new LanguageGetByIdSuccess(model);
    }
    if (state === StateEnum.license) {
      return new LicenseGetByIdSuccess(model);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetByIdSuccess(model);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetByIdSuccess(model);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static getByIdFail(state: StateEnum): GetByIdFailCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitGetByIdFail();
    }
    if (state === StateEnum.deposit) {
      return new DepositGetByIdFail();
    }
    if (state === StateEnum.language) {
      return new LanguageGetByIdFail();
    }
    if (state === StateEnum.license) {
      return new LicenseGetByIdFail();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyGetByIdFail();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyGetByIdFail();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static create<T>(state: StateEnum, model: T): CreateCrud<any> {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitCreate(model);
    }
    if (state === StateEnum.deposit) {
      return new DepositCreate(model);
    }
    if (state === StateEnum.language) {
      return new LanguageCreate(model);
    }
    if (state === StateEnum.license) {
      return new LicenseCreate(model);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyCreate(model);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyCreate(model);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static createSuccess(state: StateEnum): CreateSuccessCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitCreateSuccess();
    }
    if (state === StateEnum.deposit) {
      return new DepositCreateSuccess();
    }
    if (state === StateEnum.language) {
      return new LanguageCreateSuccess();
    }
    if (state === StateEnum.license) {
      return new LicenseCreateSuccess();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyCreateSuccess();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyCreateSuccess();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static createFail(state: StateEnum): CreateFailCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitCreateFail();
    }
    if (state === StateEnum.deposit) {
      return new DepositCreateFail();
    }
    if (state === StateEnum.language) {
      return new LanguageCreateFail();
    }
    if (state === StateEnum.license) {
      return new LicenseCreateFail();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyCreateFail();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyCreateFail();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static update<T>(state: StateEnum, model: T): UpdateCrud<any> {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitUpdate(model);
    }
    if (state === StateEnum.deposit) {
      return new DepositUpdate(model);
    }
    if (state === StateEnum.language) {
      return new LanguageUpdate(model);
    }
    if (state === StateEnum.license) {
      return new LicenseUpdate(model);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyUpdate(model);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyUpdate(model);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static updateSuccess(state: StateEnum): UpdateSuccessCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitUpdateSuccess();
    }
    if (state === StateEnum.deposit) {
      return new DepositUpdateSuccess();
    }
    if (state === StateEnum.language) {
      return new LanguageUpdateSuccess();
    }
    if (state === StateEnum.license) {
      return new LicenseUpdateSuccess();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyUpdateSuccess();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyUpdateSuccess();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static updateFail(state: StateEnum): UpdateFailCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitUpdateFail();
    }
    if (state === StateEnum.deposit) {
      return new DepositUpdateFail();
    }
    if (state === StateEnum.language) {
      return new LanguageUpdateFail();
    }
    if (state === StateEnum.license) {
      return new LicenseUpdateFail();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyUpdateFail();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyUpdateFail();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static delete(state: StateEnum, resId: string): DeleteCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitDelete(resId);
    }
    if (state === StateEnum.deposit) {
      return new DepositDelete(resId);
    }
    if (state === StateEnum.language) {
      return new LanguageDelete(resId);
    }
    if (state === StateEnum.license) {
      return new LicenseDelete(resId);
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyDelete(resId);
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyDelete(resId);
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static deleteSuccess(state: StateEnum): DeleteSuccessCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitDeleteSuccess();
    }
    if (state === StateEnum.deposit) {
      return new DepositDeleteSuccess();
    }
    if (state === StateEnum.language) {
      return new LanguageDeleteSuccess();
    }
    if (state === StateEnum.license) {
      return new LicenseDeleteSuccess();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyDeleteSuccess();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyDeleteSuccess();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

  static deleteFail(state: StateEnum): DeleteFailCrud {
    if (state === StateEnum.organizationalUnit) {
      return new OrgUnitDeleteFail();
    }
    if (state === StateEnum.deposit) {
      return new DepositDeleteFail();
    }
    if (state === StateEnum.language) {
      return new LanguageDeleteFail();
    }
    if (state === StateEnum.license) {
      return new LicenseDeleteFail();
    }
    if (state === StateEnum.preservationPolicy) {
      return new PreservationPolicyDeleteFail();
    }
    if (state === StateEnum.submissionPolicy) {
      return new SubmissionPolicyDeleteFail();
    }
    throw Error(StringUtil.format(CrudActionUtil.messageNotFound, state));
  }

}
