import {CrudStateModel} from "@app/shared/crud.state";
import {CollectionTypedModel} from "@app/shared/models/collection-typed.model";
import {PagingModel} from "@app/shared/models/paging.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {ObjectUtil} from "@app/shared/utils/object.util";
import {StateContext} from "@ngxs/store";

export class CrudHelperUtil {
  static getQueryParametersToApply<T>(queryParameters: QueryParametersModel, ctx: StateContext<CrudStateModel<T>>): QueryParametersModel {
    return queryParameters == null ? ctx.getState().queryParameters : queryParameters;
  }

  static updateQueryParameters<T>(ctx: StateContext<CrudStateModel<T>>, list: CollectionTypedModel<T> | null | undefined): QueryParametersModel {
    const queryParameters = ObjectUtil.clone(ctx.getState().queryParameters);
    let paging = ObjectUtil.clone(queryParameters.paging);
    paging.length = list === null || list === undefined ? 0 : list._page.totalItems;
    paging = this.checkPagingConsistency(paging);
    queryParameters.paging = paging;
    return queryParameters;
  }

  private static checkPagingConsistency(paging: PagingModel): PagingModel {
    // TODO check current page index with the new number of items
    return paging;
  }
}
