import {LicensesModel} from "@app/generated-api";
import {ArchiveMetadataModel} from "@app/shared/models/business/archive-metadata.model";
import Metadata = ArchiveMetadataModel.Metadata;

export class MetadataUtil {
  static readonly aipDispositionApproval = "aip-disposition-approval";
  static readonly aipOrganizationalUnit = "aip-organizational-unit";
  static readonly aipRetention = "aip-retention";
  static readonly aipRetentionEnd = "aip-retention-end";
  static readonly dataciteXml = "datacite.xml";
  static readonly aipContainer = "aip-container";

  static readonly datacite = "datacite";
  static readonly dataciteResource = "datacite:resource";
  static readonly xmlnsDatacite = "xmlns:datacite";
  static readonly dataciteDates = "datacite:dates";
  static readonly dataciteDate = "datacite:date";
  static readonly dataciteTitles = "datacite:titles";
  static readonly dataciteTitle = "datacite:title";
  static readonly dataciteResourceType = "datacite:resourceType";
  static readonly resourceTypeGeneral = "resourceTypeGeneral";
  static readonly content = "content";
  static readonly dataciteRelatedIdentifiers = "datacite:relatedIdentifiers";
  static readonly dataciteRelatedIdentifier = "datacite:relatedIdentifier";
  static readonly relationType = "relationType";
  static readonly relatedIdentifierType = "relatedIdentifierType";
  static readonly xmlnsDlcm = "xmlns:dlcm";
  static readonly xmlnsMets = "xmlns:mets";
  static readonly dataciteFormats = "datacite:formats";
  static readonly dataciteFormat = "datacite:format";
  static readonly dataciteIdentifier = "datacite:identifier";
  static readonly identifierType = "identifierType";
  static readonly dataciteRightsList = "datacite:rightsList";
  static readonly dataciteRights = "datacite:rights";
  static readonly rightsURI = "rightsURI";
  static readonly xmlnsXlink = "xmlns:xlink";
  static readonly datacitePublicationYear = "datacite:publicationYear";
  static readonly datacitePublisher = "datacite:publisher";
  static readonly dataciteDescriptions = "datacite:descriptions";
  static readonly dataciteDescription = "datacite:description";
  static readonly descriptionType = "descriptionType";
  static readonly dataciteCreators = "datacite:creators";
  static readonly dataciteCreator = "datacite:creator";
  static readonly dataciteCreatorName = "datacite:creatorName";
  static readonly xmlnsFits = "xmlns:fits";
  static readonly xmlnsPremis = "xmlns:premis";
  static readonly aipUnit = "aip-unit";
  static readonly creation = "creation";

  static readonly rightsUtiForAccessLevelFinal = "https://www.dlcm.ch/access-level/final";
  static readonly rightsUtiForAccessLevel = "https://www.dlcm.ch";

  static getTitle(metadata: Metadata): string {
    return metadata[MetadataUtil.datacite][MetadataUtil.dataciteResource][MetadataUtil.dataciteTitles][MetadataUtil.dataciteTitle][0];
  }

  static getOrganizationalUnitResId(metadata: Metadata): string {
    return metadata[MetadataUtil.aipOrganizationalUnit];
  }

  static getPublicationYear(metadata: Metadata): number {
    return metadata[MetadataUtil.datacite][MetadataUtil.dataciteResource][MetadataUtil.datacitePublicationYear];
  }

  static getAccessLevel(metadata: Metadata): string {
    const listRight = MetadataUtil.getListRights(metadata);
    let accessLevel = listRight.find(r => r.rightsURI === MetadataUtil.rightsUtiForAccessLevelFinal);
    if (accessLevel !== null && accessLevel !== undefined) {
      return accessLevel.content;
    }
    accessLevel = listRight.find(r => r.rightsURI === MetadataUtil.rightsUtiForAccessLevel);
    return accessLevel === null || accessLevel === undefined ? null : accessLevel.content;
  }

  static getLicences(metadata: Metadata): LicensesModel[] {
    const listRight = MetadataUtil.getListRights(metadata);
    const licenses = listRight.filter(r => r.rightsURI !== MetadataUtil.rightsUtiForAccessLevelFinal && r.rightsURI !== MetadataUtil.rightsUtiForAccessLevel);

    const listLicences: LicensesModel[] = [];
    licenses.forEach(l => listLicences.push({title: l.content, url: l.rightsURI} as LicensesModel));
    return listLicences;
  }

  private static getListRights(metadata: Metadata): [{ rightsURI: string, content: string }] {
    return metadata[MetadataUtil.datacite][MetadataUtil.dataciteResource][MetadataUtil.dataciteRightsList][MetadataUtil.dataciteRights];
  }
}
