import {ComponentType} from "@angular/cdk/portal";
import {OnInit} from "@angular/core";
import {MatDialog} from "@angular/material";
import {ActivatedRoute} from "@angular/router";
import {CrudStateModel} from "@app/shared/crud.state";
import {AbstractDeleteDialog} from "@app/shared/dialogs/abstract-delete/abstract-delete.dialog";
import {BaseDirective} from "@app/shared/directives/base.directive";
import {StateEnum} from "@app/shared/enums/state.enum";
import {DeleteDialogModel} from "@app/shared/models/delete-dialog.model";
import {CrudActionUtil} from "@app/shared/utils/crud-action.util";
import {CrudDialogUtil} from "@app/shared/utils/crud-dialog.util";
import {CrudRouteUtil} from "@app/shared/utils/crud-route.util";
import {Navigate} from "@ngxs/router-plugin";
import {Store} from "@ngxs/store";
import {Observable} from "rxjs";
import {take} from "rxjs/operators";

export abstract class AbstractDetailView<T, U extends CrudStateModel<T>> extends BaseDirective implements OnInit {

  isLoading$: Observable<boolean>;
  current$: Observable<T>;

  abstract readonly KEY_PARAM_NAME: string;
  abstract readonly KEY_EDIT_BUTTON: string;
  abstract readonly KEY_DELETE_BUTTON: string;

  private resId: string;

  protected constructor(protected store: Store,
                        protected route: ActivatedRoute,
                        public dialog: MatDialog,
                        private state: StateEnum) {
    super();
    this.isLoading$ = this.store.select(s => (s[state] as U).isLoading);
    this.current$ = this.store.select(s => (s[state] as U).current);
  }

  ngOnInit() {
    this.retreiveCurrentModelWithUrl();
  }

  private retreiveCurrentModelWithUrl() {
    this.resId = this.route.snapshot.paramMap.get("id");
    this.getById(this.resId);
  }

  private getById(id: string) {
    this.store.dispatch(CrudActionUtil.getById(this.state, id));
  }

  edit() {
    this.store.dispatch(new Navigate([CrudRouteUtil.getEditRoute(this.state), this.resId]));
  }

  delete() {
    const datas = {} as DeleteDialogModel;
    this.addToSubscription(this.current$.pipe(take(1)).subscribe((model: T) => {
      datas.name = model[this.KEY_PARAM_NAME];
      datas.resId = model["resId"];
    }));
    const dialogRef = this.dialog.open(CrudDialogUtil.delete(this.state) as ComponentType<AbstractDeleteDialog<T, U>>, {
      width: "250px",
      data: datas,
    });
  }
}
