import {ChangeDetectionStrategy, Component, OnInit} from "@angular/core";
import {ActivatedRoute} from "@angular/router";
import {CrudStateModel} from "@app/shared/crud.state";
import {BaseDirective} from "@app/shared/directives/base.directive";
import {StateEnum} from "@app/shared/enums/state.enum";
import {CrudActionUtil} from "@app/shared/utils/crud-action.util";
import {Store} from "@ngxs/store";
import {Observable} from "rxjs";

export abstract class AbstractEditView<T, U extends CrudStateModel<T>> extends BaseDirective implements OnInit {
  isLoading$: Observable<boolean>;
  current$: Observable<T>;

  private resId: string;

  protected constructor(protected store: Store,
                        protected route: ActivatedRoute,
                        private state: StateEnum) {
    super();
    this.isLoading$ = this.store.select(s => (s[state] as U).isLoading);
    this.current$ = this.store.select(s => (s[state] as U).current);
  }

  ngOnInit() {
    this.getCurrentModel();
  }

  private getCurrentModel() {
    this.resId = this.route.snapshot.paramMap.get("id");
    this.getById(this.resId);
  }

  private getById(id: string) {
    this.store.dispatch(CrudActionUtil.getById(this.state, id));
  }

  update(model: T) {
    this.store.dispatch(CrudActionUtil.update<T>(this.state, model));
  }
}
