import {ChangeDetectionStrategy, Component, OnInit} from "@angular/core";
import {CrudStateModel} from "@app/shared/crud.state";
import {BaseDirective} from "@app/shared/directives/base.directive";
import {StateEnum} from "@app/shared/enums/state.enum";
import {DataTableColumnsModel} from "@app/shared/models/data-table-columns.model";
import {QueryParametersModel} from "@app/shared/models/query-parameters.model";
import {CrudActionUtil} from "@app/shared/utils/crud-action.util";
import {CrudRouteUtil} from "@app/shared/utils/crud-route.util";
import {Navigate} from "@ngxs/router-plugin";
import {Store} from "@ngxs/store";
import {Observable} from "rxjs";

export abstract class AbstractListView<T, U extends CrudStateModel<T>> extends BaseDirective implements OnInit {
  isLoading$: Observable<boolean>;
  list$: Observable<T[]>;
  queryParameters$: Observable<QueryParametersModel>;

  columns: DataTableColumnsModel[];

  abstract readonly KEY_CREATE_BUTTON: string;
  abstract readonly KEY_REFRESH_BUTTON: string;

  protected constructor(protected store: Store, private state: StateEnum) {
    super();
    this.isLoading$ = this.store.select(s => (s[state] as U).isLoading);
    this.list$ = this.store.select(s => (s[state] as U).list);
    this.queryParameters$ = this.store.select(s => (s[state] as U).queryParameters);
  }

  ngOnInit() {
    this.defineColumns();
    this.getAll();
  }

  abstract defineColumns();

  create() {
    this.store.dispatch(new Navigate([CrudRouteUtil.getCreateRoute(this.state)]));
  }

  getAll() {
    this.store.dispatch(CrudActionUtil.getAll(this.state));
  }

  showDetail(model: T) {
    this.store.dispatch(new Navigate([CrudRouteUtil.getDetailRoute(this.state), model["resId"]]));
  }

  onQueryParametersEvent($event: QueryParametersModel) {
    this.store.dispatch(CrudActionUtil.changeQueryParameters(this.state, $event));
  }
}
